[![CI](https://github.com/mcipc-tools/mcwb/actions/workflows/ci.yml/badge.svg)](https://github.com/mcipc-tools/mcwb/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/mcipc-tools/mcwb/branch/main/graph/badge.svg)](https://codecov.io/gh/mcipc-tools/mcwb)
[![PyPI](https://img.shields.io/pypi/v/mcwb.svg)](https://pypi.org/project/mcwb)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

# mcwb

A Minecraft world builder library.


Source          | <https://github.com/mcipc-tools/mcwb>
:---:           | :---:
PyPI            | `pip install mcwb`
Documentation   | <https://mcipc-tools.github.io/mcwb>
Releases        | <https://github.com/mcipc-tools/mcwb/releases>

## Quick start

Install mcwb from the [AUR](https://aur.archlinux.org/packages/python-mcwb/) or via:

    pip install mcwb

## Requirements
`mcwb` requires Python 3.9 or higher. It also depends on [mcipc](https://github.com/conqp/mcipc).
If you install `mcwb` via `pip`, it will automatically be installed as a dependency.

## Credits
Many thanks to all contributors to the [Minecraft Wiki](https://minecraft.gamepedia.com/) and the [Wiki.vg](https://wiki.vg/Main_Page).

## License
Copyright (C) 2018-2021 Richard Neumann <mail at richard dash neumann period de>

mcwb is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

mcwb is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with mcwb.  If not, see <http://www.gnu.org/licenses/>.

## Legal
Minecraft content and materials are trademarks and copyrights of
Mojang and its licensors. All rights reserved.
This program is free software and is not affiliated with Mojang.


<!-- README only content. Anything below this line won't be included in index.md -->

See https://mcipc-tools.github.io/mcwb for more detailed documentation.

